@@ -13,7 +13,7 @@ import (
 	"time"
 
 	"github.com/go-jose/go-jose/v3"
-	"github.com/golang-jwt/jwt"
+	"github.com/golang-jwt/jwt/v5"
 	"github.com/oauth2-proxy/oauth2-proxy/v7/pkg/apis/options"
 	"github.com/oauth2-proxy/oauth2-proxy/v7/pkg/apis/sessions"
 	"github.com/oauth2-proxy/oauth2-proxy/v7/pkg/requests"
@@ -38,8 +38,8 @@ var letters = []rune("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ")
 func randSeq(n int) string {
 	b := make([]rune, n)
 	for i := range b {
-		max := big.NewInt(int64(len(letters)))
-		bigN, err := rand.Int(rand.Reader, max)
+		maxInt := big.NewInt(int64(len(letters)))
+		bigN, err := rand.Int(rand.Reader, maxInt)
 		if err != nil {
 			// This should never happen
 			panic(err)
@@ -146,12 +146,12 @@ type loginGovCustomClaims struct {
 	Birthdate     string `json:"birthdate"`
 	AtHash        string `json:"at_hash"`
 	CHash         string `json:"c_hash"`
-	jwt.StandardClaims
+	jwt.RegisteredClaims
 }
 
 // checkNonce checks the nonce in the id_token
 func checkNonce(idToken string, p *LoginGovProvider) (err error) {
-	token, err := jwt.ParseWithClaims(idToken, &loginGovCustomClaims{}, func(token *jwt.Token) (interface{}, error) {
+	token, err := jwt.ParseWithClaims(idToken, &loginGovCustomClaims{}, func(_ *jwt.Token) (interface{}, error) {
 		var pubkeys jose.JSONWebKeySet
 		rerr := requests.New(p.PubJWKURL.String()).Do().UnmarshalInto(&pubkeys)
 		if rerr != nil {
@@ -207,12 +207,11 @@ func (p *LoginGovProvider) Redeem(ctx context.Context, _, code, codeVerifier str
 		return nil, ErrMissingCode
 	}
 
-	claims := &jwt.StandardClaims{
+	claims := &jwt.RegisteredClaims{
 		Issuer:    p.ClientID,
 		Subject:   p.ClientID,
-		Audience:  p.RedeemURL.String(),
-		ExpiresAt: time.Now().Add(5 * time.Minute).Unix(),
-		Id:        randSeq(32),
+		Audience:  jwt.ClaimStrings{p.RedeemURL.String()},
+		ExpiresAt: jwt.NewNumericDate(time.Now().Add(5 * time.Minute)),
 	}
 	token := jwt.NewWithClaims(jwt.GetSigningMethod("RS256"), claims)
 	ss, err := token.SignedString(p.JWTKey)
