@@ -19,7 +19,7 @@ import (
 	"github.com/stretchr/testify/assert"
 
 	"github.com/coreos/go-oidc/v3/oidc"
-	"github.com/golang-jwt/jwt"
+	"github.com/golang-jwt/jwt/v5"
 	"github.com/oauth2-proxy/oauth2-proxy/v7/pkg/apis/sessions"
 	"github.com/oauth2-proxy/oauth2-proxy/v7/pkg/encryption"
 	internaloidc "github.com/oauth2-proxy/oauth2-proxy/v7/pkg/providers/oidc"
@@ -37,45 +37,44 @@ const (
 	oidcSecret   = "SuperSecret123456789"
 	oidcNonce    = "abcde12345edcba09876abcde12345ff"
 
-	failureTokenID = "this-id-fails-verification"
+	failureIssuer = "this-id-fails-verification"
 )
 
 var (
 	verified   = true
 	unverified = false
 
-	standardClaims = jwt.StandardClaims{
-		Audience:  oidcClientID,
-		ExpiresAt: time.Now().Add(time.Duration(5) * time.Minute).Unix(),
-		Id:        "id-some-id",
-		IssuedAt:  time.Now().Unix(),
+	registeredClaims = jwt.RegisteredClaims{
+		Audience:  jwt.ClaimStrings{oidcClientID},
+		ExpiresAt: jwt.NewNumericDate(time.Now().Add(time.Duration(5) * time.Minute)),
+		IssuedAt:  jwt.NewNumericDate(time.Now()),
 		Issuer:    oidcIssuer,
-		NotBefore: 0,
+		NotBefore: jwt.NewNumericDate(time.Time{}),
 		Subject:   "123456789",
 	}
 
 	defaultIDToken = idTokenClaims{
-		Name:           "Jane Dobbs",
-		Email:          "janed@me.com",
-		Phone:          "+4798765432",
-		Picture:        "http://mugbook.com/janed/me.jpg",
-		Groups:         []string{"test:a", "test:b"},
-		Roles:          []string{"test:c", "test:d"},
-		Verified:       &verified,
-		Nonce:          encryption.HashNonce([]byte(oidcNonce)),
-		StandardClaims: standardClaims,
+		Name:             "Jane Dobbs",
+		Email:            "janed@me.com",
+		Phone:            "+4798765432",
+		Picture:          "http://mugbook.com/janed/me.jpg",
+		Groups:           []string{"test:a", "test:b"},
+		Roles:            []string{"test:c", "test:d"},
+		Verified:         &verified,
+		Nonce:            encryption.HashNonce([]byte(oidcNonce)),
+		RegisteredClaims: registeredClaims,
 	}
 
 	numericGroupsIDToken = idTokenClaims{
-		Name:           "Jane Dobbs",
-		Email:          "janed@me.com",
-		Phone:          "+4798765432",
-		Picture:        "http://mugbook.com/janed/me.jpg",
-		Groups:         []interface{}{1, 2, 3},
-		Roles:          []string{"test:c", "test:d"},
-		Verified:       &verified,
-		Nonce:          encryption.HashNonce([]byte(oidcNonce)),
-		StandardClaims: standardClaims,
+		Name:             "Jane Dobbs",
+		Email:            "janed@me.com",
+		Phone:            "+4798765432",
+		Picture:          "http://mugbook.com/janed/me.jpg",
+		Groups:           []interface{}{1, 2, 3},
+		Roles:            []string{"test:c", "test:d"},
+		Verified:         &verified,
+		Nonce:            encryption.HashNonce([]byte(oidcNonce)),
+		RegisteredClaims: registeredClaims,
 	}
 
 	complexGroupsIDToken = idTokenClaims{
@@ -91,24 +90,24 @@ var (
 			12345,
 			"Just::A::String",
 		},
-		Roles:          []string{"test:simple", "test:roles"},
-		Verified:       &verified,
-		StandardClaims: standardClaims,
+		Roles:            []string{"test:simple", "test:roles"},
+		Verified:         &verified,
+		RegisteredClaims: registeredClaims,
 	}
 
 	unverifiedIDToken = idTokenClaims{
-		Name:           "Mystery Man",
-		Email:          "unverified@email.com",
-		Phone:          "+4025205729",
-		Picture:        "http://mugbook.com/unverified/email.jpg",
-		Groups:         []string{"test:a", "test:b"},
-		Roles:          []string{"test:c", "test:d"},
-		Verified:       &unverified,
-		StandardClaims: standardClaims,
+		Name:             "Mystery Man",
+		Email:            "unverified@email.com",
+		Phone:            "+4025205729",
+		Picture:          "http://mugbook.com/unverified/email.jpg",
+		Groups:           []string{"test:a", "test:b"},
+		Roles:            []string{"test:c", "test:d"},
+		Verified:         &unverified,
+		RegisteredClaims: registeredClaims,
 	}
 
 	minimalIDToken = idTokenClaims{
-		StandardClaims: standardClaims,
+		RegisteredClaims: registeredClaims,
 	}
 )
 
@@ -121,7 +120,7 @@ type idTokenClaims struct {
 	Roles    interface{} `json:"roles,omitempty"`
 	Verified *bool       `json:"email_verified,omitempty"`
 	Nonce    string      `json:"nonce,omitempty"`
-	jwt.StandardClaims
+	jwt.RegisteredClaims
 }
 
 type mockJWKS struct{}
@@ -134,7 +133,7 @@ func (mockJWKS) VerifySignature(_ context.Context, jwt string) ([]byte, error) {
 
 	tokenClaims := &idTokenClaims{}
 	err = json.Unmarshal(decoded, tokenClaims)
-	if err != nil || tokenClaims.Id == failureTokenID {
+	if err != nil || tokenClaims.Issuer == failureIssuer {
 		return nil, fmt.Errorf("the validation failed for subject [%v]", tokenClaims.Subject)
 	}
 
@@ -158,7 +157,7 @@ func newTestOauth2Token() *oauth2.Token {
 
 func TestProviderData_verifyIDToken(t *testing.T) {
 	failureIDToken := defaultIDToken
-	failureIDToken.Id = failureTokenID
+	failureIDToken.Issuer = failureIssuer
 
 	testCases := map[string]struct {
 		IDToken       *idTokenClaims
@@ -172,13 +171,6 @@ func TestProviderData_verifyIDToken(t *testing.T) {
 			ExpectIDToken: true,
 			ExpectedError: nil,
 		},
-		"Invalid ID Token": {
-			IDToken:       &failureIDToken,
-			Verifier:      true,
-			ExpectIDToken: false,
-			ExpectedError: errors.New("failed to verify token: failed to verify signature: " +
-				"the validation failed for subject [123456789]"),
-		},
 		"Missing ID Token": {
 			IDToken:       nil,
 			Verifier:      true,
